"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.reservation import (
    Reservation,
)
from mindbodypublicapi.models.response_details import (
    ResponseDetails,
)


class CreateReservationResponse(object):
    """Implementation of the 'CreateReservationResponse' model.

    Contains information about the create reservation response.

    Attributes:
        reservation (Reservation): Contains information about the reservation.
        response_details (ResponseDetails): Contains information about the response
            message detail.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "reservation": "Reservation",
        "response_details": "ResponseDetails",
    }

    _optionals = [
        "reservation",
        "response_details",
    ]

    def __init__(
        self,
        reservation=APIHelper.SKIP,
        response_details=APIHelper.SKIP):
        """Initialize a CreateReservationResponse instance."""
        # Initialize members of the class
        if reservation is not APIHelper.SKIP:
            self.reservation = reservation
        if response_details is not APIHelper.SKIP:
            self.response_details = response_details

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        reservation =\
            Reservation.from_dictionary(
                dictionary.get("Reservation"))\
                if "Reservation" in dictionary.keys()\
                else APIHelper.SKIP
        response_details =\
            ResponseDetails.from_dictionary(
                dictionary.get("ResponseDetails"))\
                if "ResponseDetails" in dictionary.keys()\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(reservation,
                   response_details)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _reservation=(
            self.reservation
            if hasattr(self, "reservation")
            else None
        )
        _response_details=(
            self.response_details
            if hasattr(self, "response_details")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"reservation={_reservation!r}, "
            f"response_details={_response_details!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _reservation=(
            self.reservation
            if hasattr(self, "reservation")
            else None
        )
        _response_details=(
            self.response_details
            if hasattr(self, "response_details")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"reservation={_reservation!s}, "
            f"response_details={_response_details!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class UploadClientDocumentResponse(object):
    """Implementation of the 'UploadClientDocumentResponse' model.

    Attributes:
        file_size (int): The size of the uploaded file.
        file_name (str): The name of the uploaded file.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "file_size": "FileSize",
        "file_name": "FileName",
    }

    _optionals = [
        "file_size",
        "file_name",
    ]

    def __init__(
        self,
        file_size=APIHelper.SKIP,
        file_name=APIHelper.SKIP):
        """Initialize a UploadClientDocumentResponse instance."""
        # Initialize members of the class
        if file_size is not APIHelper.SKIP:
            self.file_size = file_size
        if file_name is not APIHelper.SKIP:
            self.file_name = file_name

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        file_size =\
            dictionary.get("FileSize")\
            if dictionary.get("FileSize")\
                else APIHelper.SKIP
        file_name =\
            dictionary.get("FileName")\
            if dictionary.get("FileName")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(file_size,
                   file_name)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _file_size=(
            self.file_size
            if hasattr(self, "file_size")
            else None
        )
        _file_name=(
            self.file_name
            if hasattr(self, "file_name")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"file_size={_file_size!r}, "
            f"file_name={_file_name!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _file_size=(
            self.file_size
            if hasattr(self, "file_size")
            else None
        )
        _file_name=(
            self.file_name
            if hasattr(self, "file_name")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"file_size={_file_size!s}, "
            f"file_name={_file_name!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.pagination_response import (
    PaginationResponse,
)
from mindbodypublicapi.models.product import (
    Product,
)


class GetProductsResponse(object):
    """Implementation of the 'GetProductsResponse' model.

    Represents the response object for retrieving products.

    Attributes:
        pagination_response (PaginationResponse): Contains information about the
            pagination to use.
        products (List[Product]): Contains information about the products.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "pagination_response": "PaginationResponse",
        "products": "Products",
    }

    _optionals = [
        "pagination_response",
        "products",
    ]

    def __init__(
        self,
        pagination_response=APIHelper.SKIP,
        products=APIHelper.SKIP):
        """Initialize a GetProductsResponse instance."""
        # Initialize members of the class
        if pagination_response is not APIHelper.SKIP:
            self.pagination_response = pagination_response
        if products is not APIHelper.SKIP:
            self.products = products

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        pagination_response =\
            PaginationResponse.from_dictionary(
                dictionary.get("PaginationResponse"))\
                if "PaginationResponse" in dictionary.keys()\
                else APIHelper.SKIP
        products = None
        if dictionary.get("Products") is not None:
            products = [
                Product.from_dictionary(x)
                    for x in dictionary.get("Products")
            ]
        else:
            products = APIHelper.SKIP

        # Return an object of this model
        return cls(pagination_response,
                   products)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _pagination_response=(
            self.pagination_response
            if hasattr(self, "pagination_response")
            else None
        )
        _products=(
            self.products
            if hasattr(self, "products")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"pagination_response={_pagination_response!r}, "
            f"products={_products!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _pagination_response=(
            self.pagination_response
            if hasattr(self, "pagination_response")
            else None
        )
        _products=(
            self.products
            if hasattr(self, "products")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"pagination_response={_pagination_response!s}, "
            f"products={_products!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.class_description import (
    ClassDescription,
)
from mindbodypublicapi.models.client import (
    Client,
)
from mindbodypublicapi.models.course import (
    Course,
)
from mindbodypublicapi.models.location import (
    Location,
)
from mindbodypublicapi.models.mclass import (
    Class,
)
from mindbodypublicapi.models.staff import Staff


class ClassSchedule(object):
    """Implementation of the 'ClassSchedule' model.

    Represents a single class instance. The class meets at the start time, goes until
    the end time.

    Attributes:
        classes (List[Class]): Contains information about a class.
        clients (List[Client]): Contains information about clients.
        course (Course): A course.
        semester_id (int): The semester ID for the enrollment (if any).
        is_available (bool): When `true`, indicates that the enrollment shows in
            consumer mode, has not started yet, and there is room in each class of
            the enrollment.<br />  When `false`, indicates that either the enrollment
            does not show in consumer mode, has already started, or there is no room
            in some classes of the enrollment.
        id (int): The unique ID of the class schedule.
        class_description (ClassDescription): Represents a class definition. The
            class meets at the start time, goes until the end time.
        day_sunday (bool): When `true`, indicates that this schedule occurs on
            Sundays.
        day_monday (bool): When `true`, indicates that this schedule occurs on
            Mondays.
        day_tuesday (bool): When `true`, indicates that this schedule occurs on
            Tuesdays.
        day_wednesday (bool): When `true`, indicates that this schedule occurs on
            Wednesdays.
        day_thursday (bool): When `true`, indicates that this schedule occurs on
            Thursdays.
        day_friday (bool): When `true`, indicates that this schedule occurs on
            Fridays.
        day_saturday (bool): When `true`, indicates that this schedule occurs on
            Saturdays.
        allow_open_enrollment (bool): When `true`, indicates that the enrollment
            allows booking after the enrollment has started.
        allow_date_forward_enrollment (bool): When `true`, indicates that this the
            enrollment shows in consumer mode, the enrollment has not started yet,
            and there is room in each class of the enrollment.
        start_time (datetime): The time this class schedule starts.
        end_time (datetime): The time this class schedule ends.
        start_date (datetime): The date this class schedule starts.
        end_date (datetime): The date this class schedule ends.
        staff (Staff): The Staff
        location (Location): The model property of type Location.
        frequency_type (FrequencyTypeEnum): The class schedule recurrence type.
        frequency_interval (int): The interval between class schedule occurencies.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "classes": "Classes",
        "clients": "Clients",
        "course": "Course",
        "semester_id": "SemesterId",
        "is_available": "IsAvailable",
        "id": "Id",
        "class_description": "ClassDescription",
        "day_sunday": "DaySunday",
        "day_monday": "DayMonday",
        "day_tuesday": "DayTuesday",
        "day_wednesday": "DayWednesday",
        "day_thursday": "DayThursday",
        "day_friday": "DayFriday",
        "day_saturday": "DaySaturday",
        "allow_open_enrollment": "AllowOpenEnrollment",
        "allow_date_forward_enrollment": "AllowDateForwardEnrollment",
        "start_time": "StartTime",
        "end_time": "EndTime",
        "start_date": "StartDate",
        "end_date": "EndDate",
        "staff": "Staff",
        "location": "Location",
        "frequency_type": "FrequencyType",
        "frequency_interval": "FrequencyInterval",
    }

    _optionals = [
        "classes",
        "clients",
        "course",
        "semester_id",
        "is_available",
        "id",
        "class_description",
        "day_sunday",
        "day_monday",
        "day_tuesday",
        "day_wednesday",
        "day_thursday",
        "day_friday",
        "day_saturday",
        "allow_open_enrollment",
        "allow_date_forward_enrollment",
        "start_time",
        "end_time",
        "start_date",
        "end_date",
        "staff",
        "location",
        "frequency_type",
        "frequency_interval",
    ]

    def __init__(
        self,
        classes=APIHelper.SKIP,
        clients=APIHelper.SKIP,
        course=APIHelper.SKIP,
        semester_id=APIHelper.SKIP,
        is_available=APIHelper.SKIP,
        id=APIHelper.SKIP,
        class_description=APIHelper.SKIP,
        day_sunday=APIHelper.SKIP,
        day_monday=APIHelper.SKIP,
        day_tuesday=APIHelper.SKIP,
        day_wednesday=APIHelper.SKIP,
        day_thursday=APIHelper.SKIP,
        day_friday=APIHelper.SKIP,
        day_saturday=APIHelper.SKIP,
        allow_open_enrollment=APIHelper.SKIP,
        allow_date_forward_enrollment=APIHelper.SKIP,
        start_time=APIHelper.SKIP,
        end_time=APIHelper.SKIP,
        start_date=APIHelper.SKIP,
        end_date=APIHelper.SKIP,
        staff=APIHelper.SKIP,
        location=APIHelper.SKIP,
        frequency_type=APIHelper.SKIP,
        frequency_interval=APIHelper.SKIP):
        """Initialize a ClassSchedule instance."""
        # Initialize members of the class
        if classes is not APIHelper.SKIP:
            self.classes = classes
        if clients is not APIHelper.SKIP:
            self.clients = clients
        if course is not APIHelper.SKIP:
            self.course = course
        if semester_id is not APIHelper.SKIP:
            self.semester_id = semester_id
        if is_available is not APIHelper.SKIP:
            self.is_available = is_available
        if id is not APIHelper.SKIP:
            self.id = id
        if class_description is not APIHelper.SKIP:
            self.class_description = class_description
        if day_sunday is not APIHelper.SKIP:
            self.day_sunday = day_sunday
        if day_monday is not APIHelper.SKIP:
            self.day_monday = day_monday
        if day_tuesday is not APIHelper.SKIP:
            self.day_tuesday = day_tuesday
        if day_wednesday is not APIHelper.SKIP:
            self.day_wednesday = day_wednesday
        if day_thursday is not APIHelper.SKIP:
            self.day_thursday = day_thursday
        if day_friday is not APIHelper.SKIP:
            self.day_friday = day_friday
        if day_saturday is not APIHelper.SKIP:
            self.day_saturday = day_saturday
        if allow_open_enrollment is not APIHelper.SKIP:
            self.allow_open_enrollment = allow_open_enrollment
        if allow_date_forward_enrollment is not APIHelper.SKIP:
            self.allow_date_forward_enrollment = allow_date_forward_enrollment
        if start_time is not APIHelper.SKIP:
            self.start_time =\
                 APIHelper.apply_datetime_converter(
                start_time, APIHelper.RFC3339DateTime)\
                 if start_time else None
        if end_time is not APIHelper.SKIP:
            self.end_time =\
                 APIHelper.apply_datetime_converter(
                end_time, APIHelper.RFC3339DateTime)\
                 if end_time else None
        if start_date is not APIHelper.SKIP:
            self.start_date =\
                 APIHelper.apply_datetime_converter(
                start_date, APIHelper.RFC3339DateTime)\
                 if start_date else None
        if end_date is not APIHelper.SKIP:
            self.end_date =\
                 APIHelper.apply_datetime_converter(
                end_date, APIHelper.RFC3339DateTime)\
                 if end_date else None
        if staff is not APIHelper.SKIP:
            self.staff = staff
        if location is not APIHelper.SKIP:
            self.location = location
        if frequency_type is not APIHelper.SKIP:
            self.frequency_type = frequency_type
        if frequency_interval is not APIHelper.SKIP:
            self.frequency_interval = frequency_interval

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        classes = None
        if dictionary.get("Classes") is not None:
            classes = [
                Class.from_dictionary(x)
                    for x in dictionary.get("Classes")
            ]
        else:
            classes = APIHelper.SKIP
        clients = None
        if dictionary.get("Clients") is not None:
            clients = [
                Client.from_dictionary(x)
                    for x in dictionary.get("Clients")
            ]
        else:
            clients = APIHelper.SKIP
        course =\
            Course.from_dictionary(
                dictionary.get("Course"))\
                if "Course" in dictionary.keys()\
                else APIHelper.SKIP
        semester_id =\
            dictionary.get("SemesterId")\
            if dictionary.get("SemesterId")\
                else APIHelper.SKIP
        is_available =\
            dictionary.get("IsAvailable")\
            if "IsAvailable" in dictionary.keys()\
                else APIHelper.SKIP
        id =\
            dictionary.get("Id")\
            if dictionary.get("Id")\
                else APIHelper.SKIP
        class_description =\
            ClassDescription.from_dictionary(
                dictionary.get("ClassDescription"))\
                if "ClassDescription" in dictionary.keys()\
                else APIHelper.SKIP
        day_sunday =\
            dictionary.get("DaySunday")\
            if "DaySunday" in dictionary.keys()\
                else APIHelper.SKIP
        day_monday =\
            dictionary.get("DayMonday")\
            if "DayMonday" in dictionary.keys()\
                else APIHelper.SKIP
        day_tuesday =\
            dictionary.get("DayTuesday")\
            if "DayTuesday" in dictionary.keys()\
                else APIHelper.SKIP
        day_wednesday =\
            dictionary.get("DayWednesday")\
            if "DayWednesday" in dictionary.keys()\
                else APIHelper.SKIP
        day_thursday =\
            dictionary.get("DayThursday")\
            if "DayThursday" in dictionary.keys()\
                else APIHelper.SKIP
        day_friday =\
            dictionary.get("DayFriday")\
            if "DayFriday" in dictionary.keys()\
                else APIHelper.SKIP
        day_saturday =\
            dictionary.get("DaySaturday")\
            if "DaySaturday" in dictionary.keys()\
                else APIHelper.SKIP
        allow_open_enrollment =\
            dictionary.get("AllowOpenEnrollment")\
            if "AllowOpenEnrollment" in dictionary.keys()\
                else APIHelper.SKIP
        allow_date_forward_enrollment =\
            dictionary.get("AllowDateForwardEnrollment")\
            if "AllowDateForwardEnrollment" in dictionary.keys()\
                else APIHelper.SKIP
        start_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("StartTime")).datetime\
            if dictionary.get("StartTime") else APIHelper.SKIP
        end_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("EndTime")).datetime\
            if dictionary.get("EndTime") else APIHelper.SKIP
        start_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("StartDate")).datetime\
            if dictionary.get("StartDate") else APIHelper.SKIP
        end_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("EndDate")).datetime\
            if dictionary.get("EndDate") else APIHelper.SKIP
        staff =\
            Staff.from_dictionary(
                dictionary.get("Staff"))\
                if "Staff" in dictionary.keys()\
                else APIHelper.SKIP
        location =\
            Location.from_dictionary(
                dictionary.get("Location"))\
                if "Location" in dictionary.keys()\
                else APIHelper.SKIP
        frequency_type =\
            dictionary.get("FrequencyType")\
            if dictionary.get("FrequencyType")\
                else APIHelper.SKIP
        frequency_interval =\
            dictionary.get("FrequencyInterval")\
            if dictionary.get("FrequencyInterval")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(classes,
                   clients,
                   course,
                   semester_id,
                   is_available,
                   id,
                   class_description,
                   day_sunday,
                   day_monday,
                   day_tuesday,
                   day_wednesday,
                   day_thursday,
                   day_friday,
                   day_saturday,
                   allow_open_enrollment,
                   allow_date_forward_enrollment,
                   start_time,
                   end_time,
                   start_date,
                   end_date,
                   staff,
                   location,
                   frequency_type,
                   frequency_interval)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _classes=(
            self.classes
            if hasattr(self, "classes")
            else None
        )
        _clients=(
            self.clients
            if hasattr(self, "clients")
            else None
        )
        _course=(
            self.course
            if hasattr(self, "course")
            else None
        )
        _semester_id=(
            self.semester_id
            if hasattr(self, "semester_id")
            else None
        )
        _is_available=(
            self.is_available
            if hasattr(self, "is_available")
            else None
        )
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _class_description=(
            self.class_description
            if hasattr(self, "class_description")
            else None
        )
        _day_sunday=(
            self.day_sunday
            if hasattr(self, "day_sunday")
            else None
        )
        _day_monday=(
            self.day_monday
            if hasattr(self, "day_monday")
            else None
        )
        _day_tuesday=(
            self.day_tuesday
            if hasattr(self, "day_tuesday")
            else None
        )
        _day_wednesday=(
            self.day_wednesday
            if hasattr(self, "day_wednesday")
            else None
        )
        _day_thursday=(
            self.day_thursday
            if hasattr(self, "day_thursday")
            else None
        )
        _day_friday=(
            self.day_friday
            if hasattr(self, "day_friday")
            else None
        )
        _day_saturday=(
            self.day_saturday
            if hasattr(self, "day_saturday")
            else None
        )
        _allow_open_enrollment=(
            self.allow_open_enrollment
            if hasattr(self, "allow_open_enrollment")
            else None
        )
        _allow_date_forward_enrollment=(
            self.allow_date_forward_enrollment
            if hasattr(self, "allow_date_forward_enrollment")
            else None
        )
        _start_time=(
            self.start_time
            if hasattr(self, "start_time")
            else None
        )
        _end_time=(
            self.end_time
            if hasattr(self, "end_time")
            else None
        )
        _start_date=(
            self.start_date
            if hasattr(self, "start_date")
            else None
        )
        _end_date=(
            self.end_date
            if hasattr(self, "end_date")
            else None
        )
        _staff=(
            self.staff
            if hasattr(self, "staff")
            else None
        )
        _location=(
            self.location
            if hasattr(self, "location")
            else None
        )
        _frequency_type=(
            self.frequency_type
            if hasattr(self, "frequency_type")
            else None
        )
        _frequency_interval=(
            self.frequency_interval
            if hasattr(self, "frequency_interval")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"classes={_classes!r}, "
            f"clients={_clients!r}, "
            f"course={_course!r}, "
            f"semester_id={_semester_id!r}, "
            f"is_available={_is_available!r}, "
            f"id={_id!r}, "
            f"class_description={_class_description!r}, "
            f"day_sunday={_day_sunday!r}, "
            f"day_monday={_day_monday!r}, "
            f"day_tuesday={_day_tuesday!r}, "
            f"day_wednesday={_day_wednesday!r}, "
            f"day_thursday={_day_thursday!r}, "
            f"day_friday={_day_friday!r}, "
            f"day_saturday={_day_saturday!r}, "
            f"allow_open_enrollment={_allow_open_enrollment!r}, "
            f"allow_date_forward_enrollment={_allow_date_forward_enrollment!r}, "
            f"start_time={_start_time!r}, "
            f"end_time={_end_time!r}, "
            f"start_date={_start_date!r}, "
            f"end_date={_end_date!r}, "
            f"staff={_staff!r}, "
            f"location={_location!r}, "
            f"frequency_type={_frequency_type!r}, "
            f"frequency_interval={_frequency_interval!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _classes=(
            self.classes
            if hasattr(self, "classes")
            else None
        )
        _clients=(
            self.clients
            if hasattr(self, "clients")
            else None
        )
        _course=(
            self.course
            if hasattr(self, "course")
            else None
        )
        _semester_id=(
            self.semester_id
            if hasattr(self, "semester_id")
            else None
        )
        _is_available=(
            self.is_available
            if hasattr(self, "is_available")
            else None
        )
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _class_description=(
            self.class_description
            if hasattr(self, "class_description")
            else None
        )
        _day_sunday=(
            self.day_sunday
            if hasattr(self, "day_sunday")
            else None
        )
        _day_monday=(
            self.day_monday
            if hasattr(self, "day_monday")
            else None
        )
        _day_tuesday=(
            self.day_tuesday
            if hasattr(self, "day_tuesday")
            else None
        )
        _day_wednesday=(
            self.day_wednesday
            if hasattr(self, "day_wednesday")
            else None
        )
        _day_thursday=(
            self.day_thursday
            if hasattr(self, "day_thursday")
            else None
        )
        _day_friday=(
            self.day_friday
            if hasattr(self, "day_friday")
            else None
        )
        _day_saturday=(
            self.day_saturday
            if hasattr(self, "day_saturday")
            else None
        )
        _allow_open_enrollment=(
            self.allow_open_enrollment
            if hasattr(self, "allow_open_enrollment")
            else None
        )
        _allow_date_forward_enrollment=(
            self.allow_date_forward_enrollment
            if hasattr(self, "allow_date_forward_enrollment")
            else None
        )
        _start_time=(
            self.start_time
            if hasattr(self, "start_time")
            else None
        )
        _end_time=(
            self.end_time
            if hasattr(self, "end_time")
            else None
        )
        _start_date=(
            self.start_date
            if hasattr(self, "start_date")
            else None
        )
        _end_date=(
            self.end_date
            if hasattr(self, "end_date")
            else None
        )
        _staff=(
            self.staff
            if hasattr(self, "staff")
            else None
        )
        _location=(
            self.location
            if hasattr(self, "location")
            else None
        )
        _frequency_type=(
            self.frequency_type
            if hasattr(self, "frequency_type")
            else None
        )
        _frequency_interval=(
            self.frequency_interval
            if hasattr(self, "frequency_interval")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"classes={_classes!s}, "
            f"clients={_clients!s}, "
            f"course={_course!s}, "
            f"semester_id={_semester_id!s}, "
            f"is_available={_is_available!s}, "
            f"id={_id!s}, "
            f"class_description={_class_description!s}, "
            f"day_sunday={_day_sunday!s}, "
            f"day_monday={_day_monday!s}, "
            f"day_tuesday={_day_tuesday!s}, "
            f"day_wednesday={_day_wednesday!s}, "
            f"day_thursday={_day_thursday!s}, "
            f"day_friday={_day_friday!s}, "
            f"day_saturday={_day_saturday!s}, "
            f"allow_open_enrollment={_allow_open_enrollment!s}, "
            f"allow_date_forward_enrollment={_allow_date_forward_enrollment!s}, "
            f"start_time={_start_time!s}, "
            f"end_time={_end_time!s}, "
            f"start_date={_start_date!s}, "
            f"end_date={_end_date!s}, "
            f"staff={_staff!s}, "
            f"location={_location!s}, "
            f"frequency_type={_frequency_type!s}, "
            f"frequency_interval={_frequency_interval!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
import os
import warnings
from enum import Enum

from apimatic_core.http.configurations.http_client_configuration import (
    HttpClientConfiguration,
)
from apimatic_requests_client_adapter.requests_client import (
    RequestsClient,
)
from dotenv import load_dotenv

from mindbodypublicapi.http.proxy_settings import (
    ProxySettings,
)


class Environment(Enum):
    """An enum for SDK environments."""

    PRODUCTION = 0

    @classmethod
    def from_value(cls, value, default=None):
        """Convert a value (string or int) to an Environment enum member.

        Args:
            value (Union[str, int]): The value to convert.
            default (Environment): The fallback enum member if conversion fails.

        Returns:
            Environment: Matching enum member or fallback if invalid.

        """
        if value is None:
            return default

        # Try to match directly by enum member
        if isinstance(value, cls):
            return value

        # Handle integer or string conversion
        for member in cls:
            if (str(member.value).lower() == str(value).lower()
                or member.name.lower() == str(value).lower()):
                return member

        # Fallback to provided default
        return default


class Server(Enum):
    """An enum for API servers."""

    DEFAULT = 0

    @classmethod
    def from_value(cls, value, default=None):
        """Convert a value (string or int) to a Server enum member.

        Args:
            value (Union[str, int]): The value to convert.
            default (Server): The fallback enum member if conversion fails.

        Returns:
            Server: Matching enum member or fallback if invalid.

        """
        if value is None:
            return default

        # Try to match directly by enum member
        if isinstance(value, cls):
            return value

        # Handle integer or string conversion
        for member in cls:
            if (str(member.value).lower() == str(value).lower()
                or member.name.lower() == str(value).lower()):
                return member

        # Fallback to provided default
        return default


class Configuration(HttpClientConfiguration):
    """A class used for configuring the SDK by a user."""

    @property
    def environment(self):
        """Return current environment."""
        return self._environment

    @property
    def api_key(self):
        """Return ApiKey from CustomHeaderAuthenticationCredentials."""
        return self._custom_header_authentication_credentials.api_key

    @property
    def custom_header_authentication_credentials(self):
        """Return CustomHeaderAuthenticationCredentials."""
        return self._custom_header_authentication_credentials

    def __init__(self, http_client_instance=None,
                 override_http_client_configuration=False, http_call_back=None,
                 timeout=60, max_retries=0, backoff_factor=2, retry_statuses=None,
                 retry_methods=None, proxy_settings=None,
                 environment=Environment.PRODUCTION, api_key=None,
                 custom_header_authentication_credentials=None):
        """Initialize Configuration object."""
        if retry_methods is None:
            retry_methods = ["GET", "PUT"]

        if retry_statuses is None:
            retry_statuses = [408, 413, 429, 500, 502, 503, 504, 521,
                522, 524]

        super().__init__(
            http_client_instance=http_client_instance,
            override_http_client_configuration=override_http_client_configuration,
            http_call_back=http_call_back, timeout=timeout,
            max_retries=max_retries, backoff_factor=backoff_factor,
            retry_statuses=retry_statuses, retry_methods=retry_methods,
            proxy_settings=proxy_settings,
        )

        # Current API environment
        self._environment = environment

        self._custom_header_authentication_credentials =\
            self.create_auth_credentials_object(
                api_key, custom_header_authentication_credentials)

        # The Http Client to use for making requests.
        self.set_http_client(self.create_http_client())

    def clone_with(self, http_client_instance=None,
                   override_http_client_configuration=None, http_call_back=None,
                   timeout=None, max_retries=None, backoff_factor=None,
                   retry_statuses=None, retry_methods=None, proxy_settings=None,
                   environment=None, api_key=None,
                   custom_header_authentication_credentials=None):
        """Clone configuration with overrides."""
        http_client_instance = http_client_instance or self.http_client_instance
        override_http_client_configuration =\
            (override_http_client_configuration
            or self.override_http_client_configuration)
        http_call_back = http_call_back or self.http_callback
        timeout = timeout or self.timeout
        max_retries = max_retries or self.max_retries
        backoff_factor = backoff_factor or self.backoff_factor
        retry_statuses = retry_statuses or self.retry_statuses
        retry_methods = retry_methods or self.retry_methods
        proxy_settings = proxy_settings or self.proxy_settings
        environment = environment or self.environment
        custom_header_authentication_credentials = self.create_auth_credentials_object(
            api_key,
            custom_header_authentication_credentials
            or self.custom_header_authentication_credentials,
            stack_level=3)
        return Configuration(
            http_client_instance=http_client_instance,
            override_http_client_configuration=override_http_client_configuration,
            http_call_back=http_call_back, timeout=timeout, max_retries=max_retries,
            backoff_factor=backoff_factor, retry_statuses=retry_statuses,
            retry_methods=retry_methods, proxy_settings=proxy_settings,
            environment=environment,
            custom_header_authentication_credentials=custom_header_authentication_credentials,
        )

    def create_http_client(self):
        """Create the HTTP client instance."""
        return RequestsClient(
            timeout=self.timeout, max_retries=self.max_retries,
            backoff_factor=self.backoff_factor, retry_statuses=self.retry_statuses,
            retry_methods=self.retry_methods,
            http_client_instance=self.http_client_instance,
            override_http_client_configuration=self.override_http_client_configuration,
            response_factory=self.http_response_factory,
            proxies=self.proxy_settings.to_proxies() if self.proxy_settings else None,
        )

    # All the environments the SDK can run in
    environments = {
        Environment.PRODUCTION: {
            Server.DEFAULT: "https://api.mindbodyonline.com",
        },
    }

    def get_base_uri(self, server=Server.DEFAULT):
        """Generate the appropriate base URI for the environment and the server.

        Args:
            server (Configuration.Server): The server enum for which the base
            URI is required.

        Returns:
            String: The base URI.

        """
        return self.environments[self.environment][server]

    @staticmethod
    def create_auth_credentials_object(api_key,
                                       custom_header_authentication_credentials,
                                       stack_level=4):
        """Create auth credentials object."""
        if api_key is None:
            return custom_header_authentication_credentials

        warnings.warn(message=("The 'api_key' params are deprecated. Use 'custom_head"
                               "er_authentication_credentials' param instead."),
                      category=DeprecationWarning,
                      stacklevel=stack_level)

        if custom_header_authentication_credentials is not None:
            return custom_header_authentication_credentials.clone_with(api_key)

        from mindbodypublicapi.http.auth.custom_header_authentication import (
            CustomHeaderAuthenticationCredentials,
        )
        return CustomHeaderAuthenticationCredentials(api_key)

    @classmethod
    def from_environment(cls, dotenv_path=None, **overrides):
        """Create Configuration object from .env and environment variables.

        Args:
            dotenv_path (str, optional): Path to the .env file to load.
             If None, the default .env file is used.
            **overrides: Optional values overriding setting from environment variables.

        Returns:
            Configuration: A configuration object populated with the resolved values.

        """
        # load .env automatically
        load_dotenv(dotenv_path or None, override=True)

        override_http_client_configuration = os.getenv(
            "OVERRIDE_HTTP_CLIENT_CONFIGURATION", "false").lower() == "true"
        timeout = int(os.getenv("TIMEOUT", "60"))
        max_retries = int(os.getenv("MAX_RETRIES", "0"))
        backoff_factor = float(os.getenv("BACKOFF_FACTOR", "2"))
        statuses = os.getenv("RETRY_STATUSES", None)
        retry_statuses = [int(v.strip()) for v in statuses.split(",")
                          if v.strip().isdigit()] if statuses else None
        methods = os.getenv("RETRY_METHODS", None)
        retry_methods = [v.strip() for v in methods.split(",") if v.strip()]\
            if methods else None
        environment = Environment.from_value(
            os.getenv("ENVIRONMENT"), Environment.PRODUCTION)

        from mindbodypublicapi.http.auth.custom_header_authentication import (
            CustomHeaderAuthenticationCredentials,
        )

        # Preparing default configuration
        default_config = cls(
            override_http_client_configuration=override_http_client_configuration,
            timeout=timeout,
            max_retries=max_retries,
            backoff_factor=backoff_factor,
            retry_statuses=retry_statuses,
            retry_methods=retry_methods,
            environment=environment,
            proxy_settings=ProxySettings.from_environment(),
            custom_header_authentication_credentials=CustomHeaderAuthenticationCredentials.from_environment(),
        )

        return default_config.clone_with(**overrides)



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class PaginationResponse(object):
    """Implementation of the 'PaginationResponse' model.

    Contains information about the pagination to use.

    Attributes:
        requested_limit (int): Limit from pagination request
        requested_offset (int): Offset from pagination request
        page_size (int): Number of results returned in this response
        total_results (int): Total number of results in dataset

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "requested_limit": "RequestedLimit",
        "requested_offset": "RequestedOffset",
        "page_size": "PageSize",
        "total_results": "TotalResults",
    }

    _optionals = [
        "requested_limit",
        "requested_offset",
        "page_size",
        "total_results",
    ]

    def __init__(
        self,
        requested_limit=APIHelper.SKIP,
        requested_offset=APIHelper.SKIP,
        page_size=APIHelper.SKIP,
        total_results=APIHelper.SKIP):
        """Initialize a PaginationResponse instance."""
        # Initialize members of the class
        if requested_limit is not APIHelper.SKIP:
            self.requested_limit = requested_limit
        if requested_offset is not APIHelper.SKIP:
            self.requested_offset = requested_offset
        if page_size is not APIHelper.SKIP:
            self.page_size = page_size
        if total_results is not APIHelper.SKIP:
            self.total_results = total_results

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        requested_limit =\
            dictionary.get("RequestedLimit")\
            if dictionary.get("RequestedLimit")\
                else APIHelper.SKIP
        requested_offset =\
            dictionary.get("RequestedOffset")\
            if dictionary.get("RequestedOffset")\
                else APIHelper.SKIP
        page_size =\
            dictionary.get("PageSize")\
            if dictionary.get("PageSize")\
                else APIHelper.SKIP
        total_results =\
            dictionary.get("TotalResults")\
            if dictionary.get("TotalResults")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(requested_limit,
                   requested_offset,
                   page_size,
                   total_results)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _requested_limit=(
            self.requested_limit
            if hasattr(self, "requested_limit")
            else None
        )
        _requested_offset=(
            self.requested_offset
            if hasattr(self, "requested_offset")
            else None
        )
        _page_size=(
            self.page_size
            if hasattr(self, "page_size")
            else None
        )
        _total_results=(
            self.total_results
            if hasattr(self, "total_results")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"requested_limit={_requested_limit!r}, "
            f"requested_offset={_requested_offset!r}, "
            f"page_size={_page_size!r}, "
            f"total_results={_total_results!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _requested_limit=(
            self.requested_limit
            if hasattr(self, "requested_limit")
            else None
        )
        _requested_offset=(
            self.requested_offset
            if hasattr(self, "requested_offset")
            else None
        )
        _page_size=(
            self.page_size
            if hasattr(self, "page_size")
            else None
        )
        _total_results=(
            self.total_results
            if hasattr(self, "total_results")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"requested_limit={_requested_limit!s}, "
            f"requested_offset={_requested_offset!s}, "
            f"page_size={_page_size!s}, "
            f"total_results={_total_results!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.level import Level
from mindbodypublicapi.models.program import (
    Program,
)
from mindbodypublicapi.models.session_type import (
    SessionType,
)


class ClassDescription(object):
    """Implementation of the 'ClassDescription' model.

    Represents a class definition. The class meets at the start time, goes until the
    end time.

    Attributes:
        active (bool): When `true`, indicates that the business can assign this class
            description to new class schedules.<br />  When `false`, indicates that
            the business cannot assign this class description to new class schedules.
        description (str): The long version of the class description.
        id (int): The class description's ID.
        image_url (str): The class description's image URL, if any. If it does not
            exist, nothing is returned.
        last_updated (datetime): The date this class description was last modified.
        level (Level): A session level.
        name (str): The name of this class description.
        notes (str): Any notes about the class description.
        prereq (str): Any prerequisites for the class.
        program (Program): The model property of type Program.
        session_type (SessionType): SessionType contains information about the
            session types in a business.
        category (str): The category of this class description.
        category_id (int): The category ID of this class description.
        subcategory (str): The subcategory of this class description.
        subcategory_id (int): The subcategory ID of this class description.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "active": "Active",
        "description": "Description",
        "id": "Id",
        "image_url": "ImageURL",
        "last_updated": "LastUpdated",
        "level": "Level",
        "name": "Name",
        "notes": "Notes",
        "prereq": "Prereq",
        "program": "Program",
        "session_type": "SessionType",
        "category": "Category",
        "category_id": "CategoryId",
        "subcategory": "Subcategory",
        "subcategory_id": "SubcategoryId",
    }

    _optionals = [
        "active",
        "description",
        "id",
        "image_url",
        "last_updated",
        "level",
        "name",
        "notes",
        "prereq",
        "program",
        "session_type",
        "category",
        "category_id",
        "subcategory",
        "subcategory_id",
    ]

    def __init__(
        self,
        active=APIHelper.SKIP,
        description=APIHelper.SKIP,
        id=APIHelper.SKIP,
        image_url=APIHelper.SKIP,
        last_updated=APIHelper.SKIP,
        level=APIHelper.SKIP,
        name=APIHelper.SKIP,
        notes=APIHelper.SKIP,
        prereq=APIHelper.SKIP,
        program=APIHelper.SKIP,
        session_type=APIHelper.SKIP,
        category=APIHelper.SKIP,
        category_id=APIHelper.SKIP,
        subcategory=APIHelper.SKIP,
        subcategory_id=APIHelper.SKIP):
        """Initialize a ClassDescription instance."""
        # Initialize members of the class
        if active is not APIHelper.SKIP:
            self.active = active
        if description is not APIHelper.SKIP:
            self.description = description
        if id is not APIHelper.SKIP:
            self.id = id
        if image_url is not APIHelper.SKIP:
            self.image_url = image_url
        if last_updated is not APIHelper.SKIP:
            self.last_updated =\
                 APIHelper.apply_datetime_converter(
                last_updated, APIHelper.RFC3339DateTime)\
                 if last_updated else None
        if level is not APIHelper.SKIP:
            self.level = level
        if name is not APIHelper.SKIP:
            self.name = name
        if notes is not APIHelper.SKIP:
            self.notes = notes
        if prereq is not APIHelper.SKIP:
            self.prereq = prereq
        if program is not APIHelper.SKIP:
            self.program = program
        if session_type is not APIHelper.SKIP:
            self.session_type = session_type
        if category is not APIHelper.SKIP:
            self.category = category
        if category_id is not APIHelper.SKIP:
            self.category_id = category_id
        if subcategory is not APIHelper.SKIP:
            self.subcategory = subcategory
        if subcategory_id is not APIHelper.SKIP:
            self.subcategory_id = subcategory_id

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        active =\
            dictionary.get("Active")\
            if "Active" in dictionary.keys()\
                else APIHelper.SKIP
        description =\
            dictionary.get("Description")\
            if dictionary.get("Description")\
                else APIHelper.SKIP
        id =\
            dictionary.get("Id")\
            if dictionary.get("Id")\
                else APIHelper.SKIP
        image_url =\
            dictionary.get("ImageURL")\
            if dictionary.get("ImageURL")\
                else APIHelper.SKIP
        last_updated = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("LastUpdated")).datetime\
            if dictionary.get("LastUpdated") else APIHelper.SKIP
        level =\
            Level.from_dictionary(
                dictionary.get("Level"))\
                if "Level" in dictionary.keys()\
                else APIHelper.SKIP
        name =\
            dictionary.get("Name")\
            if dictionary.get("Name")\
                else APIHelper.SKIP
        notes =\
            dictionary.get("Notes")\
            if dictionary.get("Notes")\
                else APIHelper.SKIP
        prereq =\
            dictionary.get("Prereq")\
            if dictionary.get("Prereq")\
                else APIHelper.SKIP
        program =\
            Program.from_dictionary(
                dictionary.get("Program"))\
                if "Program" in dictionary.keys()\
                else APIHelper.SKIP
        session_type =\
            SessionType.from_dictionary(
                dictionary.get("SessionType"))\
                if "SessionType" in dictionary.keys()\
                else APIHelper.SKIP
        category =\
            dictionary.get("Category")\
            if dictionary.get("Category")\
                else APIHelper.SKIP
        category_id =\
            dictionary.get("CategoryId")\
            if dictionary.get("CategoryId")\
                else APIHelper.SKIP
        subcategory =\
            dictionary.get("Subcategory")\
            if dictionary.get("Subcategory")\
                else APIHelper.SKIP
        subcategory_id =\
            dictionary.get("SubcategoryId")\
            if dictionary.get("SubcategoryId")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(active,
                   description,
                   id,
                   image_url,
                   last_updated,
                   level,
                   name,
                   notes,
                   prereq,
                   program,
                   session_type,
                   category,
                   category_id,
                   subcategory,
                   subcategory_id)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _active=(
            self.active
            if hasattr(self, "active")
            else None
        )
        _description=(
            self.description
            if hasattr(self, "description")
            else None
        )
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _image_url=(
            self.image_url
            if hasattr(self, "image_url")
            else None
        )
        _last_updated=(
            self.last_updated
            if hasattr(self, "last_updated")
            else None
        )
        _level=(
            self.level
            if hasattr(self, "level")
            else None
        )
        _name=(
            self.name
            if hasattr(self, "name")
            else None
        )
        _notes=(
            self.notes
            if hasattr(self, "notes")
            else None
        )
        _prereq=(
            self.prereq
            if hasattr(self, "prereq")
            else None
        )
        _program=(
            self.program
            if hasattr(self, "program")
            else None
        )
        _session_type=(
            self.session_type
            if hasattr(self, "session_type")
            else None
        )
        _category=(
            self.category
            if hasattr(self, "category")
            else None
        )
        _category_id=(
            self.category_id
            if hasattr(self, "category_id")
            else None
        )
        _subcategory=(
            self.subcategory
            if hasattr(self, "subcategory")
            else None
        )
        _subcategory_id=(
            self.subcategory_id
            if hasattr(self, "subcategory_id")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"active={_active!r}, "
            f"description={_description!r}, "
            f"id={_id!r}, "
            f"image_url={_image_url!r}, "
            f"last_updated={_last_updated!r}, "
            f"level={_level!r}, "
            f"name={_name!r}, "
            f"notes={_notes!r}, "
            f"prereq={_prereq!r}, "
            f"program={_program!r}, "
            f"session_type={_session_type!r}, "
            f"category={_category!r}, "
            f"category_id={_category_id!r}, "
            f"subcategory={_subcategory!r}, "
            f"subcategory_id={_subcategory_id!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _active=(
            self.active
            if hasattr(self, "active")
            else None
        )
        _description=(
            self.description
            if hasattr(self, "description")
            else None
        )
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _image_url=(
            self.image_url
            if hasattr(self, "image_url")
            else None
        )
        _last_updated=(
            self.last_updated
            if hasattr(self, "last_updated")
            else None
        )
        _level=(
            self.level
            if hasattr(self, "level")
            else None
        )
        _name=(
            self.name
            if hasattr(self, "name")
            else None
        )
        _notes=(
            self.notes
            if hasattr(self, "notes")
            else None
        )
        _prereq=(
            self.prereq
            if hasattr(self, "prereq")
            else None
        )
        _program=(
            self.program
            if hasattr(self, "program")
            else None
        )
        _session_type=(
            self.session_type
            if hasattr(self, "session_type")
            else None
        )
        _category=(
            self.category
            if hasattr(self, "category")
            else None
        )
        _category_id=(
            self.category_id
            if hasattr(self, "category_id")
            else None
        )
        _subcategory=(
            self.subcategory
            if hasattr(self, "subcategory")
            else None
        )
        _subcategory_id=(
            self.subcategory_id
            if hasattr(self, "subcategory_id")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"active={_active!s}, "
            f"description={_description!s}, "
            f"id={_id!s}, "
            f"image_url={_image_url!s}, "
            f"last_updated={_last_updated!s}, "
            f"level={_level!s}, "
            f"name={_name!s}, "
            f"notes={_notes!s}, "
            f"prereq={_prereq!s}, "
            f"program={_program!s}, "
            f"session_type={_session_type!s}, "
            f"category={_category!s}, "
            f"category_id={_category_id!s}, "
            f"subcategory={_subcategory!s}, "
            f"subcategory_id={_subcategory_id!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.resource_slim import (
    ResourceSlim,
)


class CheckoutAppointmentBookingRequest(object):
    """Implementation of the 'CheckoutAppointmentBookingRequest' model.

    Attributes:
        staff_id (int): The ID of the staff member who is to provide the service
            being booked.
        location_id (int): The ID of the location where the appointment is to take
            place.
        session_type_id (int): The ID of the session type of this appointment.
        resources (List[ResourceSlim]): Contains information about the resources to
            be used for the appointment.
        start_date_time (datetime): The date and time that the appointment is to
            start in the business’ timezone. This value must be passed in the format
            yyyy-mm-ddThh:mm:ss.
        end_date_time (datetime): The date and time that the appointment is to end in
            the business’ timezone. This value must be passed in the format
            yyyy-mm-ddThh:mm:ss.
        provider_id (str): The National Provider Identifier (NPI) of the staff member
            who is to provide the service. For an explanation of Provider IDs, see
            [Provider
            IDs](https://support.mindbodyonline.com/s/article/204075743-Provider-IDs?l
            anguage=en_US).

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "staff_id": "StaffId",
        "location_id": "LocationId",
        "session_type_id": "SessionTypeId",
        "resources": "Resources",
        "start_date_time": "StartDateTime",
        "end_date_time": "EndDateTime",
        "provider_id": "ProviderId",
    }

    _optionals = [
        "staff_id",
        "location_id",
        "session_type_id",
        "resources",
        "start_date_time",
        "end_date_time",
        "provider_id",
    ]

    def __init__(
        self,
        staff_id=APIHelper.SKIP,
        location_id=APIHelper.SKIP,
        session_type_id=APIHelper.SKIP,
        resources=APIHelper.SKIP,
        start_date_time=APIHelper.SKIP,
        end_date_time=APIHelper.SKIP,
        provider_id=APIHelper.SKIP):
        """Initialize a CheckoutAppointmentBookingRequest instance."""
        # Initialize members of the class
        if staff_id is not APIHelper.SKIP:
            self.staff_id = staff_id
        if location_id is not APIHelper.SKIP:
            self.location_id = location_id
        if session_type_id is not APIHelper.SKIP:
            self.session_type_id = session_type_id
        if resources is not APIHelper.SKIP:
            self.resources = resources
        if start_date_time is not APIHelper.SKIP:
            self.start_date_time =\
                 APIHelper.apply_datetime_converter(
                start_date_time, APIHelper.RFC3339DateTime)\
                 if start_date_time else None
        if end_date_time is not APIHelper.SKIP:
            self.end_date_time =\
                 APIHelper.apply_datetime_converter(
                end_date_time, APIHelper.RFC3339DateTime)\
                 if end_date_time else None
        if provider_id is not APIHelper.SKIP:
            self.provider_id = provider_id

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        staff_id =\
            dictionary.get("StaffId")\
            if dictionary.get("StaffId")\
                else APIHelper.SKIP
        location_id =\
            dictionary.get("LocationId")\
            if dictionary.get("LocationId")\
                else APIHelper.SKIP
        session_type_id =\
            dictionary.get("SessionTypeId")\
            if dictionary.get("SessionTypeId")\
                else APIHelper.SKIP
        resources = None
        if dictionary.get("Resources") is not None:
            resources = [
                ResourceSlim.from_dictionary(x)
                    for x in dictionary.get("Resources")
            ]
        else:
            resources = APIHelper.SKIP
        start_date_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("StartDateTime")).datetime\
            if dictionary.get("StartDateTime") else APIHelper.SKIP
        end_date_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("EndDateTime")).datetime\
            if dictionary.get("EndDateTime") else APIHelper.SKIP
        provider_id =\
            dictionary.get("ProviderId")\
            if dictionary.get("ProviderId")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(staff_id,
                   location_id,
                   session_type_id,
                   resources,
                   start_date_time,
                   end_date_time,
                   provider_id)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _staff_id=(
            self.staff_id
            if hasattr(self, "staff_id")
            else None
        )
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _session_type_id=(
            self.session_type_id
            if hasattr(self, "session_type_id")
            else None
        )
        _resources=(
            self.resources
            if hasattr(self, "resources")
            else None
        )
        _start_date_time=(
            self.start_date_time
            if hasattr(self, "start_date_time")
            else None
        )
        _end_date_time=(
            self.end_date_time
            if hasattr(self, "end_date_time")
            else None
        )
        _provider_id=(
            self.provider_id
            if hasattr(self, "provider_id")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"staff_id={_staff_id!r}, "
            f"location_id={_location_id!r}, "
            f"session_type_id={_session_type_id!r}, "
            f"resources={_resources!r}, "
            f"start_date_time={_start_date_time!r}, "
            f"end_date_time={_end_date_time!r}, "
            f"provider_id={_provider_id!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _staff_id=(
            self.staff_id
            if hasattr(self, "staff_id")
            else None
        )
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _session_type_id=(
            self.session_type_id
            if hasattr(self, "session_type_id")
            else None
        )
        _resources=(
            self.resources
            if hasattr(self, "resources")
            else None
        )
        _start_date_time=(
            self.start_date_time
            if hasattr(self, "start_date_time")
            else None
        )
        _end_date_time=(
            self.end_date_time
            if hasattr(self, "end_date_time")
            else None
        )
        _provider_id=(
            self.provider_id
            if hasattr(self, "provider_id")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"staff_id={_staff_id!s}, "
            f"location_id={_location_id!s}, "
            f"session_type_id={_session_type_id!s}, "
            f"resources={_resources!s}, "
            f"start_date_time={_start_date_time!s}, "
            f"end_date_time={_end_date_time!s}, "
            f"provider_id={_provider_id!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.sale import Sale


class UpdateSaleDateResponse(object):
    """Implementation of the 'UpdateSaleDateResponse' model.

    Update Sale Date Response Properties

    Attributes:
        sale (Sale): Contains the Sale details.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "sale": "Sale",
    }

    _optionals = [
        "sale",
    ]

    def __init__(
        self,
        sale=APIHelper.SKIP):
        """Initialize a UpdateSaleDateResponse instance."""
        # Initialize members of the class
        if sale is not APIHelper.SKIP:
            self.sale = sale

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        sale =\
            Sale.from_dictionary(
                dictionary.get("Sale"))\
                if "Sale" in dictionary.keys()\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(sale)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _sale=(
            self.sale
            if hasattr(self, "sale")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"sale={_sale!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _sale=(
            self.sale
            if hasattr(self, "sale")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"sale={_sale!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class GetClientsRequest(object):
    """Implementation of the 'GetClientsRequest' model.

    Attributes:
        client_i_ds (List[str]): The requested client IDs.  Default: **all IDs** that
            the authenticated user’s access level allows.<br />  Note: You can fetch
            information for maximum 20 clients at once.
        search_text (str): Text to use in the search. Can include FirstName,
            LastName, and Email. Note that user credentials must be provided.
        is_prospect (bool): When `true`, filters the results to include only those
            clients marked as prospects for the business.<br />  When `false`,
            indicates that only those clients who are not marked prospects should be
            returned.
        last_modified_date (datetime): Filters the results to include only the
            clients that have been modified on or after this date.
        unique_ids (List[int]): Filters results to clients with these `UniqueIDs`.
            This parameter cannot be used with `ClientIDs` or `SearchText`.  Default:
            **all UniqueIDs** that the authenticated user’s access level allows.
        include_inactive (bool): When `true`, indicates the results to include active
            and inactive clients.<br />  When `false`, indicates that only those
            clients who are marked as active should be returned.  Default: **false**
        limit (int): Number of results to include, defaults to 100
        offset (int): Page offset, defaults to 0.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "client_i_ds": "ClientIDs",
        "search_text": "SearchText",
        "is_prospect": "IsProspect",
        "last_modified_date": "LastModifiedDate",
        "unique_ids": "UniqueIds",
        "include_inactive": "IncludeInactive",
        "limit": "Limit",
        "offset": "Offset",
    }

    _optionals = [
        "client_i_ds",
        "search_text",
        "is_prospect",
        "last_modified_date",
        "unique_ids",
        "include_inactive",
        "limit",
        "offset",
    ]

    def __init__(
        self,
        client_i_ds=APIHelper.SKIP,
        search_text=APIHelper.SKIP,
        is_prospect=APIHelper.SKIP,
        last_modified_date=APIHelper.SKIP,
        unique_ids=APIHelper.SKIP,
        include_inactive=APIHelper.SKIP,
        limit=APIHelper.SKIP,
        offset=APIHelper.SKIP):
        """Initialize a GetClientsRequest instance."""
        # Initialize members of the class
        if client_i_ds is not APIHelper.SKIP:
            self.client_i_ds = client_i_ds
        if search_text is not APIHelper.SKIP:
            self.search_text = search_text
        if is_prospect is not APIHelper.SKIP:
            self.is_prospect = is_prospect
        if last_modified_date is not APIHelper.SKIP:
            self.last_modified_date =\
                 APIHelper.apply_datetime_converter(
                last_modified_date, APIHelper.RFC3339DateTime)\
                 if last_modified_date else None
        if unique_ids is not APIHelper.SKIP:
            self.unique_ids = unique_ids
        if include_inactive is not APIHelper.SKIP:
            self.include_inactive = include_inactive
        if limit is not APIHelper.SKIP:
            self.limit = limit
        if offset is not APIHelper.SKIP:
            self.offset = offset

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        client_i_ds =\
            dictionary.get("ClientIDs")\
            if dictionary.get("ClientIDs")\
                else APIHelper.SKIP
        search_text =\
            dictionary.get("SearchText")\
            if dictionary.get("SearchText")\
                else APIHelper.SKIP
        is_prospect =\
            dictionary.get("IsProspect")\
            if "IsProspect" in dictionary.keys()\
                else APIHelper.SKIP
        last_modified_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("LastModifiedDate")).datetime\
            if dictionary.get("LastModifiedDate") else APIHelper.SKIP
        unique_ids =\
            dictionary.get("UniqueIds")\
            if dictionary.get("UniqueIds")\
                else APIHelper.SKIP
        include_inactive =\
            dictionary.get("IncludeInactive")\
            if "IncludeInactive" in dictionary.keys()\
                else APIHelper.SKIP
        limit =\
            dictionary.get("Limit")\
            if dictionary.get("Limit")\
                else APIHelper.SKIP
        offset =\
            dictionary.get("Offset")\
            if dictionary.get("Offset")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(client_i_ds,
                   search_text,
                   is_prospect,
                   last_modified_date,
                   unique_ids,
                   include_inactive,
                   limit,
                   offset)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _client_i_ds=(
            self.client_i_ds
            if hasattr(self, "client_i_ds")
            else None
        )
        _search_text=(
            self.search_text
            if hasattr(self, "search_text")
            else None
        )
        _is_prospect=(
            self.is_prospect
            if hasattr(self, "is_prospect")
            else None
        )
        _last_modified_date=(
            self.last_modified_date
            if hasattr(self, "last_modified_date")
            else None
        )
        _unique_ids=(
            self.unique_ids
            if hasattr(self, "unique_ids")
            else None
        )
        _include_inactive=(
            self.include_inactive
            if hasattr(self, "include_inactive")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"client_i_ds={_client_i_ds!r}, "
            f"search_text={_search_text!r}, "
            f"is_prospect={_is_prospect!r}, "
            f"last_modified_date={_last_modified_date!r}, "
            f"unique_ids={_unique_ids!r}, "
            f"include_inactive={_include_inactive!r}, "
            f"limit={_limit!r}, "
            f"offset={_offset!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _client_i_ds=(
            self.client_i_ds
            if hasattr(self, "client_i_ds")
            else None
        )
        _search_text=(
            self.search_text
            if hasattr(self, "search_text")
            else None
        )
        _is_prospect=(
            self.is_prospect
            if hasattr(self, "is_prospect")
            else None
        )
        _last_modified_date=(
            self.last_modified_date
            if hasattr(self, "last_modified_date")
            else None
        )
        _unique_ids=(
            self.unique_ids
            if hasattr(self, "unique_ids")
            else None
        )
        _include_inactive=(
            self.include_inactive
            if hasattr(self, "include_inactive")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"client_i_ds={_client_i_ds!s}, "
            f"search_text={_search_text!s}, "
            f"is_prospect={_is_prospect!s}, "
            f"last_modified_date={_last_modified_date!s}, "
            f"unique_ids={_unique_ids!s}, "
            f"include_inactive={_include_inactive!s}, "
            f"limit={_limit!s}, "
            f"offset={_offset!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from apimatic_core.configurations.global_configuration import (
    GlobalConfiguration,
)
from apimatic_core.decorators.lazy_property import (
    LazyProperty,
)

from mindbodypublicapi.configuration import (
    Configuration,
    Environment,
)
from mindbodypublicapi.controllers.appointment_controller import (
    AppointmentController,
)
from mindbodypublicapi.controllers.base_controller import (
    BaseController,
)
from mindbodypublicapi.controllers.class_controller import (
    ClassController,
)
from mindbodypublicapi.controllers.client_controller import (
    ClientController,
)
from mindbodypublicapi.controllers.cross_site_controller import (
    CrossSiteController,
)
from mindbodypublicapi.controllers.enrollment_controller import (
    EnrollmentController,
)
from mindbodypublicapi.controllers.payroll_controller import (
    PayrollController,
)
from mindbodypublicapi.controllers.pick_a_spot_controller import (
    PickASpotController,
)
from mindbodypublicapi.controllers.pricing_option_controller import (
    PricingOptionController,
)
from mindbodypublicapi.controllers.sale_controller import (
    SaleController,
)
from mindbodypublicapi.controllers.site_controller import (
    SiteController,
)
from mindbodypublicapi.controllers.staff_controller import (
    StaffController,
)
from mindbodypublicapi.controllers.user_token_controller import (
    UserTokenController,
)
from mindbodypublicapi.http.auth.custom_header_authentication import (
    CustomHeaderAuthentication,
)


class MindbodypublicapiClient(object):
    """Client that provide access to the MindbodypublicapiClient APIs."""

    @LazyProperty
    def appointment(self):
        """Provide access to the AppointmentController endpoints."""
        return AppointmentController(self.global_configuration)

    @LazyProperty
    def mclass(self):
        """Provide access to the ClassController endpoints."""
        return ClassController(self.global_configuration)

    @LazyProperty
    def client(self):
        """Provide access to the ClientController endpoints."""
        return ClientController(self.global_configuration)

    @LazyProperty
    def cross_site(self):
        """Provide access to the CrossSiteController endpoints."""
        return CrossSiteController(self.global_configuration)

    @LazyProperty
    def enrollment(self):
        """Provide access to the EnrollmentController endpoints."""
        return EnrollmentController(self.global_configuration)

    @LazyProperty
    def payroll(self):
        """Provide access to the PayrollController endpoints."""
        return PayrollController(self.global_configuration)

    @LazyProperty
    def pick_a_spot(self):
        """Provide access to the PickASpotController endpoints."""
        return PickASpotController(self.global_configuration)

    @LazyProperty
    def pricing_option(self):
        """Provide access to the PricingOptionController endpoints."""
        return PricingOptionController(self.global_configuration)

    @LazyProperty
    def sale(self):
        """Provide access to the SaleController endpoints."""
        return SaleController(self.global_configuration)

    @LazyProperty
    def site(self):
        """Provide access to the SiteController endpoints."""
        return SiteController(self.global_configuration)

    @LazyProperty
    def staff(self):
        """Provide access to the StaffController endpoints."""
        return StaffController(self.global_configuration)

    @LazyProperty
    def user_token(self):
        """Provide access to the UserTokenController endpoints."""
        return UserTokenController(self.global_configuration)

    def __init__(self, http_client_instance=None,
                 override_http_client_configuration=False, http_call_back=None,
                 timeout=60, max_retries=0, backoff_factor=2,
                 retry_statuses=None, retry_methods=None, proxy_settings=None,
                 environment=Environment.PRODUCTION, api_key=None,
                 custom_header_authentication_credentials=None, config=None):
        """Initialize a new instance of MindbodypublicapiClient."""
        self.config = config or Configuration(
            http_client_instance=http_client_instance,
            override_http_client_configuration=override_http_client_configuration,
            http_call_back=http_call_back, timeout=timeout,
            max_retries=max_retries, backoff_factor=backoff_factor,
            retry_statuses=retry_statuses, retry_methods=retry_methods,
            proxy_settings=proxy_settings, environment=environment,
            api_key=api_key,
            custom_header_authentication_credentials=custom_header_authentication_credentials)

        self.global_configuration = GlobalConfiguration(self.config)\
            .global_errors(BaseController.global_errors())\
            .base_uri_executor(self.config.get_base_uri)\
            .user_agent(BaseController.user_agent(),
                BaseController.user_agent_parameters())

        self.auth_managers = {
            "API-Key": CustomHeaderAuthentication(
                self.config.custom_header_authentication_credentials),
        }
        self.global_configuration =\
            self.global_configuration.auth_managers(self.auth_managers)

    @classmethod
    def from_environment(cls, dotenv_path=None, **overrides):
        """Create a client instance using environment variables.

        Returns:
            MindbodypublicapiClient instance.

        """
        return cls(config=Configuration
            .from_environment(dotenv_path=dotenv_path, **overrides))



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class GiftCardLayout(object):
    """Implementation of the 'GiftCardLayout' model.

    Gift card layout

    Attributes:
        layout_id (int): The ID of the layout.
        layout_name (str): The name of the layout.
        layout_url (str): The URL of the layout.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "layout_id": "LayoutId",
        "layout_name": "LayoutName",
        "layout_url": "LayoutUrl",
    }

    _optionals = [
        "layout_id",
        "layout_name",
        "layout_url",
    ]

    def __init__(
        self,
        layout_id=APIHelper.SKIP,
        layout_name=APIHelper.SKIP,
        layout_url=APIHelper.SKIP):
        """Initialize a GiftCardLayout instance."""
        # Initialize members of the class
        if layout_id is not APIHelper.SKIP:
            self.layout_id = layout_id
        if layout_name is not APIHelper.SKIP:
            self.layout_name = layout_name
        if layout_url is not APIHelper.SKIP:
            self.layout_url = layout_url

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        layout_id =\
            dictionary.get("LayoutId")\
            if dictionary.get("LayoutId")\
                else APIHelper.SKIP
        layout_name =\
            dictionary.get("LayoutName")\
            if dictionary.get("LayoutName")\
                else APIHelper.SKIP
        layout_url =\
            dictionary.get("LayoutUrl")\
            if dictionary.get("LayoutUrl")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(layout_id,
                   layout_name,
                   layout_url)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _layout_id=(
            self.layout_id
            if hasattr(self, "layout_id")
            else None
        )
        _layout_name=(
            self.layout_name
            if hasattr(self, "layout_name")
            else None
        )
        _layout_url=(
            self.layout_url
            if hasattr(self, "layout_url")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"layout_id={_layout_id!r}, "
            f"layout_name={_layout_name!r}, "
            f"layout_url={_layout_url!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _layout_id=(
            self.layout_id
            if hasattr(self, "layout_id")
            else None
        )
        _layout_name=(
            self.layout_name
            if hasattr(self, "layout_name")
            else None
        )
        _layout_url=(
            self.layout_url
            if hasattr(self, "layout_url")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"layout_id={_layout_id!s}, "
            f"layout_name={_layout_name!s}, "
            f"layout_url={_layout_url!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.staff import Staff


class ContactLogComment(object):
    """Implementation of the 'ContactLogComment' model.

    A contact log comment.

    Attributes:
        id (int): The comment’s ID.
        text (str): The comment’s body text.
        created_date_time (datetime): The local time when the comment was created.
        created_by (Staff): The Staff

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": "Id",
        "text": "Text",
        "created_date_time": "CreatedDateTime",
        "created_by": "CreatedBy",
    }

    _optionals = [
        "id",
        "text",
        "created_date_time",
        "created_by",
    ]

    def __init__(
        self,
        id=APIHelper.SKIP,
        text=APIHelper.SKIP,
        created_date_time=APIHelper.SKIP,
        created_by=APIHelper.SKIP):
        """Initialize a ContactLogComment instance."""
        # Initialize members of the class
        if id is not APIHelper.SKIP:
            self.id = id
        if text is not APIHelper.SKIP:
            self.text = text
        if created_date_time is not APIHelper.SKIP:
            self.created_date_time =\
                 APIHelper.apply_datetime_converter(
                created_date_time, APIHelper.RFC3339DateTime)\
                 if created_date_time else None
        if created_by is not APIHelper.SKIP:
            self.created_by = created_by

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        id =\
            dictionary.get("Id")\
            if dictionary.get("Id")\
                else APIHelper.SKIP
        text =\
            dictionary.get("Text")\
            if dictionary.get("Text")\
                else APIHelper.SKIP
        created_date_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("CreatedDateTime")).datetime\
            if dictionary.get("CreatedDateTime") else APIHelper.SKIP
        created_by =\
            Staff.from_dictionary(
                dictionary.get("CreatedBy"))\
                if "CreatedBy" in dictionary.keys()\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(id,
                   text,
                   created_date_time,
                   created_by)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _text=(
            self.text
            if hasattr(self, "text")
            else None
        )
        _created_date_time=(
            self.created_date_time
            if hasattr(self, "created_date_time")
            else None
        )
        _created_by=(
            self.created_by
            if hasattr(self, "created_by")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"id={_id!r}, "
            f"text={_text!r}, "
            f"created_date_time={_created_date_time!r}, "
            f"created_by={_created_by!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _text=(
            self.text
            if hasattr(self, "text")
            else None
        )
        _created_date_time=(
            self.created_date_time
            if hasattr(self, "created_date_time")
            else None
        )
        _created_by=(
            self.created_by
            if hasattr(self, "created_by")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"id={_id!s}, "
            f"text={_text!s}, "
            f"created_date_time={_created_date_time!s}, "
            f"created_by={_created_by!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.credit_card_info import (
    CreditCardInfo,
)
from mindbodypublicapi.models.stored_card_info import (
    StoredCardInfo,
)


class PurchaseContractRequest(object):
    """Implementation of the 'PurchaseContractRequest' model.

    Attributes:
        test (bool): When `true`, the Public API validates input information, but
            does not commit it, so no client data is affected.<br />  When `false` or
            omitted, the transaction is committed, and client data is affected.<br />
            Default: **false**
        location_id (int): The ID of the location where the client is purchasing the
            contract; used for AutoPays.
        client_id (str): The ID of the client. Note that this is not the same as the
            client’s unique ID.
        unique_client_id (int): The unique ID of the client.  Note: you need to
            provide the 'UniqueClientId' OR the 'ClientId'. If both are provided, the
            'UniqueClientId' takes precedence.
        contract_id (int): The ID of the contract being purchased.
        start_date (datetime): The date that the contract starts.<br />  Default:
            **today’s date**
        first_payment_occurs (str): The date on which the first payment is to occur.
            Possible values:  * Instant  * `StartDate`
        client_signature (str): A representation of the client’s signature. This
            value can take the form of Base64-encoded byte array. The file type
            should be PNG. The picture of the client’s signature is uploaded and
            viewable from the Client Documents page in the Core Business Mode
            software. The title of the document is:<br />
            clientContractSignature-{uniquePurchasedClientContractID}-{contractName}-{
            contractStartDate}.{fileType}
        promotion_code (str): A promotion code, if one applies. Promotion codes are
            applied to items that are both marked as pay now in a contract and are
            discounted by the promotion code. If a pay now item is an autopay item,
            its autopay price is the price at the time of checkout, so, if a
            promotion code was applied, all autopays are scheduled using that
            discounted price.
        promotion_codes (List[str]): Promotion codes, if they apply. Promotion codes
            are applied to items that are both marked as pay now in a contract and
            are discounted by the promotion code. If a pay now item is an autopay
            item, its autopay price is the price at the time of checkout, so, if a
            promotion code was applied, all autopays are scheduled using that
            discounted price.
        credit_card_info (CreditCardInfo): Information about an individual credit card
        stored_card_info (StoredCardInfo): The model property of type StoredCardInfo.
        send_notifications (bool): When `true`, indicates that email and SMS
            notifications should be sent to the client after purchase.<br />
            Default: **true**
        sales_rep_id (int): The ID of the staff member to be marked as the sales rep
            for this contract sale.
        use_direct_debit (bool): When `true`, indicates that the direct debit
            information stored on the client's account is to be used to pay for the
            contract.<br />  This is only required if both `CreditCardInfo` and
            `StoredCardInfo` are not passed and `UseAccountCredit` is false.<br />
            Default: **false**
        use_account_credit (bool): When `true`, indicates that the account credit of
            the client's account is to be used to pay for the contract.<br />  This
            is only required if both `CreditCardInfo` and `StoredCardInfo` are not
            passed and `UseDirectDebit` is false. <br />  Default: **false**
        consumer_present (bool): When `true`, indicates that the consumer is present
            or otherwise able to successfully negotiate an SCA challenge. It is not a
            good idea to have this always be false as that could very likely lead to
            a bank declining all transactions for the merchant.  Defaults to
            **false**.
        payment_authentication_callback_url (str): The URL consumer is redirected to
            if the bank requests SCA. This field is only needed if ConsumerPresent is
            true.
        prorate_date (datetime): Optional, date to prorate contract

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "contract_id": "ContractId",
        "test": "Test",
        "location_id": "LocationId",
        "client_id": "ClientId",
        "unique_client_id": "UniqueClientId",
        "start_date": "StartDate",
        "first_payment_occurs": "FirstPaymentOccurs",
        "client_signature": "ClientSignature",
        "promotion_code": "PromotionCode",
        "promotion_codes": "PromotionCodes",
        "credit_card_info": "CreditCardInfo",
        "stored_card_info": "StoredCardInfo",
        "send_notifications": "SendNotifications",
        "sales_rep_id": "SalesRepId",
        "use_direct_debit": "UseDirectDebit",
        "use_account_credit": "UseAccountCredit",
        "consumer_present": "ConsumerPresent",
        "payment_authentication_callback_url": "PaymentAuthenticationCallbackUrl",
        "prorate_date": "ProrateDate",
    }

    _optionals = [
        "test",
        "location_id",
        "client_id",
        "unique_client_id",
        "start_date",
        "first_payment_occurs",
        "client_signature",
        "promotion_code",
        "promotion_codes",
        "credit_card_info",
        "stored_card_info",
        "send_notifications",
        "sales_rep_id",
        "use_direct_debit",
        "use_account_credit",
        "consumer_present",
        "payment_authentication_callback_url",
        "prorate_date",
    ]

    def __init__(
        self,
        contract_id=None,
        test=APIHelper.SKIP,
        location_id=APIHelper.SKIP,
        client_id=APIHelper.SKIP,
        unique_client_id=APIHelper.SKIP,
        start_date=APIHelper.SKIP,
        first_payment_occurs=APIHelper.SKIP,
        client_signature=APIHelper.SKIP,
        promotion_code=APIHelper.SKIP,
        promotion_codes=APIHelper.SKIP,
        credit_card_info=APIHelper.SKIP,
        stored_card_info=APIHelper.SKIP,
        send_notifications=APIHelper.SKIP,
        sales_rep_id=APIHelper.SKIP,
        use_direct_debit=APIHelper.SKIP,
        use_account_credit=APIHelper.SKIP,
        consumer_present=APIHelper.SKIP,
        payment_authentication_callback_url=APIHelper.SKIP,
        prorate_date=APIHelper.SKIP):
        """Initialize a PurchaseContractRequest instance."""
        # Initialize members of the class
        if test is not APIHelper.SKIP:
            self.test = test
        if location_id is not APIHelper.SKIP:
            self.location_id = location_id
        if client_id is not APIHelper.SKIP:
            self.client_id = client_id
        if unique_client_id is not APIHelper.SKIP:
            self.unique_client_id = unique_client_id
        self.contract_id = contract_id
        if start_date is not APIHelper.SKIP:
            self.start_date =\
                 APIHelper.apply_datetime_converter(
                start_date, APIHelper.RFC3339DateTime)\
                 if start_date else None
        if first_payment_occurs is not APIHelper.SKIP:
            self.first_payment_occurs = first_payment_occurs
        if client_signature is not APIHelper.SKIP:
            self.client_signature = client_signature
        if promotion_code is not APIHelper.SKIP:
            self.promotion_code = promotion_code
        if promotion_codes is not APIHelper.SKIP:
            self.promotion_codes = promotion_codes
        if credit_card_info is not APIHelper.SKIP:
            self.credit_card_info = credit_card_info
        if stored_card_info is not APIHelper.SKIP:
            self.stored_card_info = stored_card_info
        if send_notifications is not APIHelper.SKIP:
            self.send_notifications = send_notifications
        if sales_rep_id is not APIHelper.SKIP:
            self.sales_rep_id = sales_rep_id
        if use_direct_debit is not APIHelper.SKIP:
            self.use_direct_debit = use_direct_debit
        if use_account_credit is not APIHelper.SKIP:
            self.use_account_credit = use_account_credit
        if consumer_present is not APIHelper.SKIP:
            self.consumer_present = consumer_present
        if payment_authentication_callback_url is not APIHelper.SKIP:
            self.payment_authentication_callback_url =\
                 payment_authentication_callback_url
        if prorate_date is not APIHelper.SKIP:
            self.prorate_date =\
                 APIHelper.apply_datetime_converter(
                prorate_date, APIHelper.RFC3339DateTime)\
                 if prorate_date else None

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        contract_id =\
            dictionary.get("ContractId")\
            if dictionary.get("ContractId")\
                else None
        test =\
            dictionary.get("Test")\
            if "Test" in dictionary.keys()\
                else APIHelper.SKIP
        location_id =\
            dictionary.get("LocationId")\
            if dictionary.get("LocationId")\
                else APIHelper.SKIP
        client_id =\
            dictionary.get("ClientId")\
            if dictionary.get("ClientId")\
                else APIHelper.SKIP
        unique_client_id =\
            dictionary.get("UniqueClientId")\
            if dictionary.get("UniqueClientId")\
                else APIHelper.SKIP
        start_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("StartDate")).datetime\
            if dictionary.get("StartDate") else APIHelper.SKIP
        first_payment_occurs =\
            dictionary.get("FirstPaymentOccurs")\
            if dictionary.get("FirstPaymentOccurs")\
                else APIHelper.SKIP
        client_signature =\
            dictionary.get("ClientSignature")\
            if dictionary.get("ClientSignature")\
                else APIHelper.SKIP
        promotion_code =\
            dictionary.get("PromotionCode")\
            if dictionary.get("PromotionCode")\
                else APIHelper.SKIP
        promotion_codes =\
            dictionary.get("PromotionCodes")\
            if dictionary.get("PromotionCodes")\
                else APIHelper.SKIP
        credit_card_info =\
            CreditCardInfo.from_dictionary(
                dictionary.get("CreditCardInfo"))\
                if "CreditCardInfo" in dictionary.keys()\
                else APIHelper.SKIP
        stored_card_info =\
            StoredCardInfo.from_dictionary(
                dictionary.get("StoredCardInfo"))\
                if "StoredCardInfo" in dictionary.keys()\
                else APIHelper.SKIP
        send_notifications =\
            dictionary.get("SendNotifications")\
            if "SendNotifications" in dictionary.keys()\
                else APIHelper.SKIP
        sales_rep_id =\
            dictionary.get("SalesRepId")\
            if dictionary.get("SalesRepId")\
                else APIHelper.SKIP
        use_direct_debit =\
            dictionary.get("UseDirectDebit")\
            if "UseDirectDebit" in dictionary.keys()\
                else APIHelper.SKIP
        use_account_credit =\
            dictionary.get("UseAccountCredit")\
            if "UseAccountCredit" in dictionary.keys()\
                else APIHelper.SKIP
        consumer_present =\
            dictionary.get("ConsumerPresent")\
            if "ConsumerPresent" in dictionary.keys()\
                else APIHelper.SKIP
        payment_authentication_callback_url =\
            dictionary.get("PaymentAuthenticationCallbackUrl")\
            if dictionary.get("PaymentAuthenticationCallbackUrl")\
                else APIHelper.SKIP
        prorate_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("ProrateDate")).datetime\
            if dictionary.get("ProrateDate") else APIHelper.SKIP

        # Return an object of this model
        return cls(contract_id,
                   test,
                   location_id,
                   client_id,
                   unique_client_id,
                   start_date,
                   first_payment_occurs,
                   client_signature,
                   promotion_code,
                   promotion_codes,
                   credit_card_info,
                   stored_card_info,
                   send_notifications,
                   sales_rep_id,
                   use_direct_debit,
                   use_account_credit,
                   consumer_present,
                   payment_authentication_callback_url,
                   prorate_date)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _test=(
            self.test
            if hasattr(self, "test")
            else None
        )
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _client_id=(
            self.client_id
            if hasattr(self, "client_id")
            else None
        )
        _unique_client_id=(
            self.unique_client_id
            if hasattr(self, "unique_client_id")
            else None
        )
        _contract_id=self.contract_id
        _start_date=(
            self.start_date
            if hasattr(self, "start_date")
            else None
        )
        _first_payment_occurs=(
            self.first_payment_occurs
            if hasattr(self, "first_payment_occurs")
            else None
        )
        _client_signature=(
            self.client_signature
            if hasattr(self, "client_signature")
            else None
        )
        _promotion_code=(
            self.promotion_code
            if hasattr(self, "promotion_code")
            else None
        )
        _promotion_codes=(
            self.promotion_codes
            if hasattr(self, "promotion_codes")
            else None
        )
        _credit_card_info=(
            self.credit_card_info
            if hasattr(self, "credit_card_info")
            else None
        )
        _stored_card_info=(
            self.stored_card_info
            if hasattr(self, "stored_card_info")
            else None
        )
        _send_notifications=(
            self.send_notifications
            if hasattr(self, "send_notifications")
            else None
        )
        _sales_rep_id=(
            self.sales_rep_id
            if hasattr(self, "sales_rep_id")
            else None
        )
        _use_direct_debit=(
            self.use_direct_debit
            if hasattr(self, "use_direct_debit")
            else None
        )
        _use_account_credit=(
            self.use_account_credit
            if hasattr(self, "use_account_credit")
            else None
        )
        _consumer_present=(
            self.consumer_present
            if hasattr(self, "consumer_present")
            else None
        )
        _payment_authentication_callback_url=(
            self.payment_authentication_callback_url
            if hasattr(self, "payment_authentication_callback_url")
            else None
        )
        _prorate_date=(
            self.prorate_date
            if hasattr(self, "prorate_date")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"test={_test!r}, "
            f"location_id={_location_id!r}, "
            f"client_id={_client_id!r}, "
            f"unique_client_id={_unique_client_id!r}, "
            f"contract_id={_contract_id!r}, "
            f"start_date={_start_date!r}, "
            f"first_payment_occurs={_first_payment_occurs!r}, "
            f"client_signature={_client_signature!r}, "
            f"promotion_code={_promotion_code!r}, "
            f"promotion_codes={_promotion_codes!r}, "
            f"credit_card_info={_credit_card_info!r}, "
            f"stored_card_info={_stored_card_info!r}, "
            f"send_notifications={_send_notifications!r}, "
            f"sales_rep_id={_sales_rep_id!r}, "
            f"use_direct_debit={_use_direct_debit!r}, "
            f"use_account_credit={_use_account_credit!r}, "
            f"consumer_present={_consumer_present!r}, "
            f"payment_authentication_callback_url={_payment_authentication_callback_url!r}, "
            f"prorate_date={_prorate_date!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _test=(
            self.test
            if hasattr(self, "test")
            else None
        )
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _client_id=(
            self.client_id
            if hasattr(self, "client_id")
            else None
        )
        _unique_client_id=(
            self.unique_client_id
            if hasattr(self, "unique_client_id")
            else None
        )
        _contract_id=self.contract_id
        _start_date=(
            self.start_date
            if hasattr(self, "start_date")
            else None
        )
        _first_payment_occurs=(
            self.first_payment_occurs
            if hasattr(self, "first_payment_occurs")
            else None
        )
        _client_signature=(
            self.client_signature
            if hasattr(self, "client_signature")
            else None
        )
        _promotion_code=(
            self.promotion_code
            if hasattr(self, "promotion_code")
            else None
        )
        _promotion_codes=(
            self.promotion_codes
            if hasattr(self, "promotion_codes")
            else None
        )
        _credit_card_info=(
            self.credit_card_info
            if hasattr(self, "credit_card_info")
            else None
        )
        _stored_card_info=(
            self.stored_card_info
            if hasattr(self, "stored_card_info")
            else None
        )
        _send_notifications=(
            self.send_notifications
            if hasattr(self, "send_notifications")
            else None
        )
        _sales_rep_id=(
            self.sales_rep_id
            if hasattr(self, "sales_rep_id")
            else None
        )
        _use_direct_debit=(
            self.use_direct_debit
            if hasattr(self, "use_direct_debit")
            else None
        )
        _use_account_credit=(
            self.use_account_credit
            if hasattr(self, "use_account_credit")
            else None
        )
        _consumer_present=(
            self.consumer_present
            if hasattr(self, "consumer_present")
            else None
        )
        _payment_authentication_callback_url=(
            self.payment_authentication_callback_url
            if hasattr(self, "payment_authentication_callback_url")
            else None
        )
        _prorate_date=(
            self.prorate_date
            if hasattr(self, "prorate_date")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"test={_test!s}, "
            f"location_id={_location_id!s}, "
            f"client_id={_client_id!s}, "
            f"unique_client_id={_unique_client_id!s}, "
            f"contract_id={_contract_id!s}, "
            f"start_date={_start_date!s}, "
            f"first_payment_occurs={_first_payment_occurs!s}, "
            f"client_signature={_client_signature!s}, "
            f"promotion_code={_promotion_code!s}, "
            f"promotion_codes={_promotion_codes!s}, "
            f"credit_card_info={_credit_card_info!s}, "
            f"stored_card_info={_stored_card_info!s}, "
            f"send_notifications={_send_notifications!s}, "
            f"sales_rep_id={_sales_rep_id!s}, "
            f"use_direct_debit={_use_direct_debit!s}, "
            f"use_account_credit={_use_account_credit!s}, "
            f"consumer_present={_consumer_present!s}, "
            f"payment_authentication_callback_url={_payment_authentication_callback_url!s}, "
            f"prorate_date={_prorate_date!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class GetContactLogTypesRequest(object):
    """Implementation of the 'GetContactLogTypesRequest' model.

    Attributes:
        contact_log_type_id (int): The requested ContactLogType ID.  Default: **all**
            IDs that the authenticated user’s access level allows.
        limit (int): Number of results to include, defaults to 100
        offset (int): Page offset, defaults to 0.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "contact_log_type_id": "ContactLogTypeId",
        "limit": "Limit",
        "offset": "Offset",
    }

    _optionals = [
        "contact_log_type_id",
        "limit",
        "offset",
    ]

    def __init__(
        self,
        contact_log_type_id=APIHelper.SKIP,
        limit=APIHelper.SKIP,
        offset=APIHelper.SKIP):
        """Initialize a GetContactLogTypesRequest instance."""
        # Initialize members of the class
        if contact_log_type_id is not APIHelper.SKIP:
            self.contact_log_type_id = contact_log_type_id
        if limit is not APIHelper.SKIP:
            self.limit = limit
        if offset is not APIHelper.SKIP:
            self.offset = offset

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        contact_log_type_id =\
            dictionary.get("ContactLogTypeId")\
            if dictionary.get("ContactLogTypeId")\
                else APIHelper.SKIP
        limit =\
            dictionary.get("Limit")\
            if dictionary.get("Limit")\
                else APIHelper.SKIP
        offset =\
            dictionary.get("Offset")\
            if dictionary.get("Offset")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(contact_log_type_id,
                   limit,
                   offset)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _contact_log_type_id=(
            self.contact_log_type_id
            if hasattr(self, "contact_log_type_id")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"contact_log_type_id={_contact_log_type_id!r}, "
            f"limit={_limit!r}, "
            f"offset={_offset!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _contact_log_type_id=(
            self.contact_log_type_id
            if hasattr(self, "contact_log_type_id")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"contact_log_type_id={_contact_log_type_id!s}, "
            f"limit={_limit!s}, "
            f"offset={_offset!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class TerminateContractRequest(object):
    """Implementation of the 'TerminateContractRequest' model.

    Attributes:
        client_id (str): The ID of the client.
        client_contract_id (int): The unique ID of the sale of the contract
        termination_date (datetime): The contract termination date.
        termination_code (str): ex. Illness, Injury, Moving, BreakingContract (Note
            this can be customized by each studio).
        termination_comments (str): The comments for terminating a contract.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "client_id": "ClientId",
        "client_contract_id": "ClientContractId",
        "termination_date": "TerminationDate",
        "termination_code": "TerminationCode",
        "termination_comments": "TerminationComments",
    }

    _optionals = [
        "termination_code",
        "termination_comments",
    ]

    def __init__(
        self,
        client_id=None,
        client_contract_id=None,
        termination_date=None,
        termination_code=APIHelper.SKIP,
        termination_comments=APIHelper.SKIP):
        """Initialize a TerminateContractRequest instance."""
        # Initialize members of the class
        self.client_id = client_id
        self.client_contract_id = client_contract_id
        self.termination_date =\
             APIHelper.apply_datetime_converter(
            termination_date, APIHelper.RFC3339DateTime)\
             if termination_date else None
        if termination_code is not APIHelper.SKIP:
            self.termination_code = termination_code
        if termination_comments is not APIHelper.SKIP:
            self.termination_comments = termination_comments

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        client_id =\
            dictionary.get("ClientId")\
            if dictionary.get("ClientId")\
                else None
        client_contract_id =\
            dictionary.get("ClientContractId")\
            if dictionary.get("ClientContractId")\
                else None
        termination_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("TerminationDate")).datetime\
            if dictionary.get("TerminationDate") else None
        termination_code =\
            dictionary.get("TerminationCode")\
            if dictionary.get("TerminationCode")\
                else APIHelper.SKIP
        termination_comments =\
            dictionary.get("TerminationComments")\
            if dictionary.get("TerminationComments")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(client_id,
                   client_contract_id,
                   termination_date,
                   termination_code,
                   termination_comments)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _client_id=self.client_id
        _client_contract_id=self.client_contract_id
        _termination_date=self.termination_date
        _termination_code=(
            self.termination_code
            if hasattr(self, "termination_code")
            else None
        )
        _termination_comments=(
            self.termination_comments
            if hasattr(self, "termination_comments")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"client_id={_client_id!r}, "
            f"client_contract_id={_client_contract_id!r}, "
            f"termination_date={_termination_date!r}, "
            f"termination_code={_termination_code!r}, "
            f"termination_comments={_termination_comments!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _client_id=self.client_id
        _client_contract_id=self.client_contract_id
        _termination_date=self.termination_date
        _termination_code=(
            self.termination_code
            if hasattr(self, "termination_code")
            else None
        )
        _termination_comments=(
            self.termination_comments
            if hasattr(self, "termination_comments")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"client_id={_client_id!s}, "
            f"client_contract_id={_client_contract_id!s}, "
            f"termination_date={_termination_date!s}, "
            f"termination_code={_termination_code!s}, "
            f"termination_comments={_termination_comments!s}, "
            f")"
        )
